@@ -221,6 +221,7 @@ class RegConfPricing(OrderingBaseModel):
     group = models.ForeignKey(Group, blank=True, null=True)
     
     price = models.DecimalField(_('Price'), max_digits=21, decimal_places=2, default=0)
+    payment_required = models.NullBooleanField(help_text='A payment required before registration is accepted.')
     
     reg_form = models.ForeignKey("CustomRegForm", blank=True, null=True, 
                                  verbose_name=_("Custom Registration Form"),
@@ -499,7 +500,10 @@ class Registration(models.Model):
         config = self.event.registration_configuration
 
         balance = self.invoice.balance
-        payment_required = config.payment_required
+        if self.reg_conf_price.payment_required is None:
+            payment_required = config.payment_required
+        else:
+            payment_required = self.reg_conf_price.payment_required
 
         if self.canceled:
             return 'cancelled'
@@ -757,7 +761,11 @@ class Registrant(models.Model):
             balance = invoice.balance
         else:
             balance = 0
-        payment_required = config.payment_required
+
+        if self.pricing.payment_required is None:
+            payment_required = config.payment_required
+        else:
+            payment_required = self.pricing.payment_required
 
         if self.cancel_dt:
             return 'cancelled'
