@@ -17,19 +17,11 @@ class Command(BaseCommand):
     Usage: ./manage.py make_recurring_payment_transactions --verbosity 2
     """
     
-    def handle(self, *args, **options):
-        verbosity = 1
-        if 'verbosity' in options:
-            verbosity = options['verbosity']
-        try:
-            verbosity = int(verbosity)
-        except:
-            pass
-            
+    def handle(self, *args, **options):            
         from tendenci.addons.recurring_payments.models import RecurringPayment 
         from tendenci.addons.recurring_payments.utils import run_a_recurring_payment
-     
+
+        verbosity = int(options['verbosity'])
         recurring_payments = RecurringPayment.objects.filter(status_detail='active', status=True)    
-        
         for rp in recurring_payments:
-            run_a_recurring_payment(rp, verbosity)
\ No newline at end of file
+            run_a_recurring_payment(rp, verbosity)
